%%
% STANPARAM: settings of p-structure to 'standard' values
% (except, e.g., p.fuha.G and p.fuha.Gjac) 
%
%  p=stanparam(p)
%
% For detailed description see: <a href="matlab:web('html/settings.html')">settings</a>
function p=stanparam(p)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% FUNCTION HANDLES %%%%%%%%%%%%%%%%
p.fuha.headfu=@stanheadfu; % headline 
p.fuha.ufu=@stanufu;       % printout, stop if lam<>p.sw.lammin,p.sw.lammax
p.fuha.outfu=@stanbra;     % branch output 
p.fuha.lss=@lss;           % linear systems solver, default use \ 
p.fuha.blss=@blss;         % bordered linear system solver, default \
p.fuha.savefu=@stansavefu; %
p.fuha.postmmod=@stanpostmeshmod;
%%%%%%%%%%%%%%%%% numerical param %%%%%%%%%%%%%%%%%%%%%%%% 
p.nc.tol=1e-8;            % tol for corrector 
p.nc.imax=5;              % #of newton-iterations in corrector 
p.nc.dsmin=0.0001; p.nc.dsmax=5; % min/max stepsize 
p.nc.lammin=-1e6; p.nc.lammax=1e6; % Bif.diagram bounds 
p.nc.nsteps=10;           % number of continuation steps (multi-steps for pmcont)
p.nc.ntot=1e4;            % max total number of continuation steps 
p.nc.del=1e-8;            % perturbation size for finite differences
p.nc.lamdtol=0.5;         % parametrization switch tolerance (for p.sw.para=1)
p.nc.dsinciter=p.nc.imax/2;   % increase ds if iter < dsinciter 
p.nc.dsincfac=2;          % by this factor 
p.nc.errbound=0;          % if >0 and errchecksw>0 this bound is determines call to mesh refinement
p.nc.dlammax=1;           % max difference in lambda
p.nc.neig=50;             % # eigenvalues for eigs for G_u
p.nc.neigdet=0;           % # eigenvalues for eigs for A, 0 for LU-method
p.nc.eigref=0;            % 0 or 'sm': smallest abs value; 
                           % 'sa': smallest real part eigenvalues. CAN BE SLOW!
p.nc.eigint=[-1 0.1];     % 'sarn' eigenvalue region real part interval
p.nc.bisecmax=10;         % max # of bisections during special point locations 
p.nc.dsminbis=1e-9;       % dsmin for bif-and foldloc via bisection
%%%%% mesh-adaption 
p.nc.amod=0;              % adapt mesh each amod-th step (0 for never) 
p.nc.bddistx=0.1;         % boundary distance x for mesh-ref. for pBC
p.nc.bddisty=0.1; 
p.nc.ngen=5;              % max number of refinements during adaption 
%%%%%%%%%%%%%%%%% switches
p.sw.bifcheck=1;        % 0: off. 1: on 
p.sw.bifloc=2;          % 0 for tangent, 1 for secant, 2 for quadratic in bif.localization
p.sw.foldcheck=0;       % 0: no fold detection, 1: fold detection on.
p.sw.spcont=0;          % 0=normal continuation, 2/1=fold/branch point (zero eigenvalue) continuation
p.sw.spcalc=1;          % 1/0 to calculate/not calculate stability EVals 
p.sw.spjac=1;           % 1/0 to use fuha.spjac or not during fold/branch point cont
p.sw.sfem=0;              % switch for simple Jacobian and residual, e.g. semilinear problem:
                           % 0: off, 1: use p.fuha.sG and p.fuha.sGjac, requires call to setfemops and setting p.eqn.c, p.eqn.b, p.eqn.a 
p.sw.para=1;            % parametrization switch 
p.sw.jac=1;               % Jacobian switch, % 1: Gu analytically, else FD
p.sw.qjac=1;              % to: p.eqn.qjsw            % 1: qu analytically, else FD 
p.sw.newt=0;              % 0=newton, 1=chord, 2=...  
p.sw.norm='inf';        % norm and tol for corrector 
p.sw.errcheck=0;        % 0: off, 1: put err-est to p.sol.err, but no further action 
                        % 2: meshadac if p.sol.err>p.nc.errbound, >2: as for 2 but refine mesh 
p.sw.eigmeth='eigs';      % eigendata computation method 'eigs' or 'sarn'
p.sw.evopts.disp=0;       % don't display anything during EVal calculations
p.sw.eigsstart=1;         % 0 to use random start for eigs, 1 for [1;...;1]  
p.sw.inter=1;p.sw.verb=1;   % interaction/verbosity switch: 0=none, 1=some, 2=much
p.sw.bprint=[];               % #branchcompos for printout by outfu
p.sw.bcper=0;             % type of bc: 0 normal, 1 up=down cylinder, 2 left=right cylinder, 3 torus
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PLOTTING %%%%%%%%%%%%%%%%%%%%%%%%%%%
p.plot.pstyle=1;          % solution plot style: 1 for mesh-plot of u, 2 for contour-plot, 
                          % 3 for surface, with lightning, 4 for only the mesh
p.plot.pfig=1;            % screen layout of profile figure
p.plot.brfig=2;           % same for branch figure
p.plot.ifig=6;            % same for info figure
p.plot.pmod=1;            % plot every pmod-th step, 
p.plot.pcmp=1; p.plot.bpcmp=0; % component of sol. resp. branch for plotting 
p.plot.cm='cool';         % colormap 
p.plot.lpos=[0 0 10];     % light-pos for pstyle=3
p.plot.axis='tight';      % choose, e.g., 'tight', 'equal', 'image' 
p.plot.fs=16;             % fontsize for sol-plots, 
p.plot.labelsw=0;         % 1/0 for labels/no labels in solplot
p.plot.spfig=4;           % figure number for spectral output with spcalc (or specGu)
p.plot.brafig=3;          % figure number for standard post-computation plotting of branch
p.plot.spfig2=6;          % figure number for spectral output of bordered matrix Gua used in jaccheck
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% FILE HANDLING %%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
p.file.pnamesw=0;         % 1 to automatically set prefix of file names to variable name
p.file.mdir='meshes';     % dir so save meshes if ms=0; 
p.file.dirchecksw=0;      % 1 for user check if directories need to be created, 
                          % or written into if exist;  0 no check
p.file.smod=5;            % save ev. smod-th step, 0 for none 
p.file.count=0; p.file.bcount=1; p.file.fcount=1; % counter for step/branching/fold points 
p.file.msave=1;           % mesh saving: 1 save mesh in every point, 0 only save mesh if it is changed 
p.file.single=0;          % 0 save p.u, p.tau, p.sol.muv, and p.branch as double, 1 save as single
%%% TIMING, times only for reference, values set in cont/pmcont  %%%%%%%% 
p.time.timesw=1;          % 1 for output at end of cont
p.time.tot=0; p.time.totst=0; p.time.st=0; % times: total, total for steps, current step
p.time.bif=0; p.time.spec=0; p.time.newton=0; % times for: bifcheck, spcalc, nloop 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PMCONT %%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
p.pm.resfac=0.2;          % resi-improvement for pmcont 
p.pm.mst=10;              % #predictors for pmcont 
p.pm.imax=1;              % base-max-iterations for pmcont 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% fsolve 
p.fsol.fsol=0;            % use fsolve? 0:no, 1:pde, 2:ext, 3: both
p.fsol.meth=1;            % 1=trust-reg., else Levenberg-Marquardt
p.fsol.disp=3;            % 0=off, 1=final, 2=notify, 3=iter
p.fsol.tol=p.nc.tol^2; p.fsol.imax=5; 
p.fsol.opt=optimset('Jacobian','on','PrecondBandWidth',0);
%%%%%%%%%%%%%%%%%%%%%%%%%%%% INTIALIZATIONS FOR STARTUP %%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
p.sol.deta=0;             % determinant of linearization -- change is used to detect bif
p.sol.err=0;              % a posteriori error estimate
p.sol.meth=' ';           % string code for continuation step method 'arc', or 'nat'. See p.sw.para
p.sol.res=0;              % residual of solution in norm p.sw.norm
p.sol.iter=0;             % number of iterations used for this solution
p.sol.ineg=-1;            % number of negative (i.e. unstable) eigenvalues
p.sol.muv=[];             % eigenvectors
p.sol.lamd=0;             % step length in primary parameter (from tangent vector)
p.sol.restart=1;          % 1: make initial steps, 0: use tangent p.tau 
p.tau=1;                  % tangent vector, here trivially initialized
p.branch=[];              % branch, here trivially initialized
p.u=[];                   % solution, here trivially initialized
p.sol.xiq=0;              % weight of auxiliary eqns for arclength scalar product (needs to exist)
p.mat.fill=1;             % fill operator (nontrivial in case of periodic b.c.)
p.mat.drop=1;             % drop operator (nontrivial in case of periodic b.c.)
p.mat.M=[]; p.mat.K=[];   % empty mass and stiffness matrices 
p.mesh=[];                % the FEM mesh
p.mesh.sympoi=0;          % if 1 then make poimesh symmetric
p.sol.ptype=-99;          % initial point type;
p.usrlam=[];              % desired lam-values
p.nc.nq=0;                % number of auxiliary equations
